summaryrefslogtreecommitdiffstats
path: root/controller-api
diff options
context:
space:
mode:
authorMartin Polden <mpolden@mpolden.no>2019-08-21 15:30:33 +0200
committerMartin Polden <mpolden@mpolden.no>2019-08-21 15:31:09 +0200
commit390dc9e7f62d9c3cce0e6f5a63aaab1c7e9771a6 (patch)
tree5f9415677120d8e573a1e77c88b63b637e6f1e30 /controller-api
parentebaeab3586618252f4e28237de070b48e743e87a (diff)
Change getHealthStatus return type
Diffstat (limited to 'controller-api')
-rw-r--r--controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/routing/GlobalRoutingService.java6
1 files changed, 4 insertions, 2 deletions
diff --git a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/routing/GlobalRoutingService.java b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/routing/GlobalRoutingService.java
index 3c5d18cbc2a..9f81a54a168 100644
--- a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/routing/GlobalRoutingService.java
+++ b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/routing/GlobalRoutingService.java
@@ -1,6 +1,8 @@
// Copyright 2019 Oath Inc. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root.
package com.yahoo.vespa.hosted.controller.api.integration.routing;
+import com.yahoo.config.provision.zone.ZoneId;
+
import java.util.Map;
/**
@@ -10,7 +12,7 @@ import java.util.Map;
*/
public interface GlobalRoutingService {
- /** Returns the health status for each endpoint behind the given rotation name */
- Map<String, RotationStatus> getHealthStatus(String rotationName);
+ /** Returns the health status of each zone behind the given rotation name */
+ Map<ZoneId, RotationStatus> getHealthStatus(String rotationName);
}